aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rwxr-xr-xcompile.sh3
-rw-r--r--examples/cpp/BUILD (renamed from base_workspace/examples/cpp/BUILD)0
-rw-r--r--examples/cpp/README.md (renamed from base_workspace/examples/cpp/README.md)0
-rw-r--r--examples/cpp/hello-fail.cc (renamed from base_workspace/examples/cpp/hello-fail.cc)0
-rw-r--r--examples/cpp/hello-lib.cc (renamed from base_workspace/examples/cpp/hello-lib.cc)0
-rw-r--r--examples/cpp/hello-lib.h (renamed from base_workspace/examples/cpp/hello-lib.h)0
-rw-r--r--examples/cpp/hello-world.cc (renamed from base_workspace/examples/cpp/hello-world.cc)0
-rw-r--r--examples/gen/BUILD (renamed from base_workspace/examples/gen/BUILD)0
-rw-r--r--examples/go/BUILD (renamed from base_workspace/examples/go/BUILD)0
-rw-r--r--examples/go/README.md (renamed from base_workspace/examples/go/README.md)0
-rw-r--r--examples/go/fib.go (renamed from base_workspace/examples/go/fib.go)0
-rw-r--r--examples/go/lib1/BUILD (renamed from base_workspace/examples/go/lib1/BUILD)0
-rw-r--r--examples/go/lib1/fail_test.go (renamed from base_workspace/examples/go/lib1/fail_test.go)0
-rw-r--r--examples/go/lib1/lib1.go (renamed from base_workspace/examples/go/lib1/lib1.go)0
-rw-r--r--examples/go/lib1/lib1_test.go (renamed from base_workspace/examples/go/lib1/lib1_test.go)0
-rw-r--r--examples/java-native/README.md (renamed from base_workspace/examples/java-native/README.md)0
-rw-r--r--examples/java-native/src/main/java/com/example/myproject/BUILD (renamed from base_workspace/examples/java-native/src/main/java/com/example/myproject/BUILD)0
-rw-r--r--examples/java-native/src/main/java/com/example/myproject/Greeter.java (renamed from base_workspace/examples/java-native/src/main/java/com/example/myproject/Greeter.java)0
-rw-r--r--examples/java-native/src/main/resources/BUILD (renamed from base_workspace/examples/java-native/src/main/resources/BUILD)0
-rw-r--r--examples/java-native/src/main/resources/greeting.txt (renamed from base_workspace/examples/java-native/src/main/resources/greeting.txt)0
-rw-r--r--examples/java-native/src/test/java/com/example/myproject/BUILD (renamed from base_workspace/examples/java-native/src/test/java/com/example/myproject/BUILD)0
-rw-r--r--examples/java-native/src/test/java/com/example/myproject/Fail.java (renamed from base_workspace/examples/java-native/src/test/java/com/example/myproject/Fail.java)0
-rw-r--r--examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java (renamed from base_workspace/examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java)0
-rw-r--r--examples/java-native/src/test/java/com/example/myproject/TestHello.java (renamed from base_workspace/examples/java-native/src/test/java/com/example/myproject/TestHello.java)0
-rw-r--r--examples/java-skylark/README.md (renamed from base_workspace/examples/java-skylark/README.md)0
-rw-r--r--examples/java-skylark/src/main/java/com/example/myproject/BUILD (renamed from base_workspace/examples/java-skylark/src/main/java/com/example/myproject/BUILD)0
-rw-r--r--examples/java-skylark/src/main/java/com/example/myproject/Greeter.java (renamed from base_workspace/examples/java-skylark/src/main/java/com/example/myproject/Greeter.java)0
-rw-r--r--examples/java-skylark/src/main/resources/BUILD (renamed from base_workspace/examples/java-skylark/src/main/resources/BUILD)0
-rw-r--r--examples/java-skylark/src/main/resources/greeting.txt (renamed from base_workspace/examples/java-skylark/src/main/resources/greeting.txt)0
-rw-r--r--examples/java-skylark/src/test/java/com/example/myproject/BUILD (renamed from base_workspace/examples/java-skylark/src/test/java/com/example/myproject/BUILD)0
-rw-r--r--examples/java-skylark/src/test/java/com/example/myproject/Fail.java (renamed from base_workspace/examples/java-skylark/src/test/java/com/example/myproject/Fail.java)0
-rw-r--r--examples/java-skylark/src/test/java/com/example/myproject/TestHello.java (renamed from base_workspace/examples/java-skylark/src/test/java/com/example/myproject/TestHello.java)0
-rw-r--r--examples/objc/BUILD (renamed from base_workspace/examples/objc/BUILD)0
-rw-r--r--examples/objc/PrenotCalculator/AppDelegate.h (renamed from base_workspace/examples/objc/PrenotCalculator/AppDelegate.h)0
-rw-r--r--examples/objc/PrenotCalculator/AppDelegate.m (renamed from base_workspace/examples/objc/PrenotCalculator/AppDelegate.m)0
-rw-r--r--examples/objc/PrenotCalculator/CalculatedValues.h (renamed from base_workspace/examples/objc/PrenotCalculator/CalculatedValues.h)0
-rw-r--r--examples/objc/PrenotCalculator/CalculatedValues.m (renamed from base_workspace/examples/objc/PrenotCalculator/CalculatedValues.m)0
-rw-r--r--examples/objc/PrenotCalculator/CalculatorViewController.h (renamed from base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.h)0
-rw-r--r--examples/objc/PrenotCalculator/CalculatorViewController.m (renamed from base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.m)0
-rw-r--r--examples/objc/PrenotCalculator/CalculatorViewController.xib (renamed from base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.xib)0
-rw-r--r--examples/objc/PrenotCalculator/CoreData.h (renamed from base_workspace/examples/objc/PrenotCalculator/CoreData.h)0
-rw-r--r--examples/objc/PrenotCalculator/CoreData.m (renamed from base_workspace/examples/objc/PrenotCalculator/CoreData.m)0
-rw-r--r--examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion (renamed from base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion)0
-rw-r--r--examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents (renamed from base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents)0
-rw-r--r--examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents (renamed from base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents)0
-rw-r--r--examples/objc/PrenotCalculator/Equation.h (renamed from base_workspace/examples/objc/PrenotCalculator/Equation.h)0
-rw-r--r--examples/objc/PrenotCalculator/Equation.m (renamed from base_workspace/examples/objc/PrenotCalculator/Equation.m)0
-rw-r--r--examples/objc/PrenotCalculator/Expression.h (renamed from base_workspace/examples/objc/PrenotCalculator/Expression.h)0
-rw-r--r--examples/objc/PrenotCalculator/Expression.m (renamed from base_workspace/examples/objc/PrenotCalculator/Expression.m)0
-rw-r--r--examples/objc/PrenotCalculator/Literal.h (renamed from base_workspace/examples/objc/PrenotCalculator/Literal.h)0
-rw-r--r--examples/objc/PrenotCalculator/Literal.m (renamed from base_workspace/examples/objc/PrenotCalculator/Literal.m)0
-rw-r--r--examples/objc/PrenotCalculator/PrenotCalculator-Info.plist (renamed from base_workspace/examples/objc/PrenotCalculator/PrenotCalculator-Info.plist)0
-rw-r--r--examples/objc/PrenotCalculator/Resources/test.txt (renamed from base_workspace/examples/objc/PrenotCalculator/Resources/test.txt)0
-rw-r--r--examples/objc/PrenotCalculator/ValuesViewController.h (renamed from base_workspace/examples/objc/PrenotCalculator/ValuesViewController.h)0
-rw-r--r--examples/objc/PrenotCalculator/ValuesViewController.m (renamed from base_workspace/examples/objc/PrenotCalculator/ValuesViewController.m)0
-rw-r--r--examples/objc/PrenotCalculator/main.m (renamed from base_workspace/examples/objc/PrenotCalculator/main.m)0
-rw-r--r--examples/objc/README.md (renamed from base_workspace/examples/objc/README.md)0
-rw-r--r--examples/objc/expression_prebuilt.a (renamed from base_workspace/examples/objc/expression_prebuilt.a)bin9460 -> 9460 bytes
-rw-r--r--examples/proto/BUILD (renamed from base_workspace/examples/proto/BUILD)0
-rw-r--r--examples/proto/test.proto (renamed from base_workspace/examples/proto/test.proto)0
-rw-r--r--examples/py/BUILD (renamed from base_workspace/examples/py/BUILD)0
-rw-r--r--examples/py/bin.py (renamed from base_workspace/examples/py/bin.py)0
-rw-r--r--examples/py/lib.py (renamed from base_workspace/examples/py/lib.py)0
63 files changed, 2 insertions, 1 deletions
diff --git a/base_workspace/examples/cpp/BUILD b/examples/cpp/BUILD
index 195bbb3d25..195bbb3d25 100644
--- a/base_workspace/examples/cpp/BUILD
+++ b/examples/cpp/BUILD
diff --git a/base_workspace/examples/cpp/README.md b/examples/cpp/README.md
index fba714321c..fba714321c 100644
--- a/base_workspace/examples/cpp/README.md
+++ b/examples/cpp/README.md
diff --git a/base_workspace/examples/cpp/hello-fail.cc b/examples/cpp/hello-fail.cc
index 5b561cb0ce..5b561cb0ce 100644
--- a/base_workspace/examples/cpp/hello-fail.cc
+++ b/examples/cpp/hello-fail.cc
diff --git a/base_workspace/examples/cpp/hello-lib.cc b/examples/cpp/hello-lib.cc
index 8e40921cee..8e40921cee 100644
--- a/base_workspace/examples/cpp/hello-lib.cc
+++ b/examples/cpp/hello-lib.cc
diff --git a/base_workspace/examples/cpp/hello-lib.h b/examples/cpp/hello-lib.h
index 555d177936..555d177936 100644
--- a/base_workspace/examples/cpp/hello-lib.h
+++ b/examples/cpp/hello-lib.h
diff --git a/base_workspace/examples/cpp/hello-world.cc b/examples/cpp/hello-world.cc
index be435c3256..be435c3256 100644
--- a/base_workspace/examples/cpp/hello-world.cc
+++ b/examples/cpp/hello-world.cc
diff --git a/base_workspace/examples/gen/BUILD b/examples/gen/BUILD
index 988fa8b7de..988fa8b7de 100644
--- a/base_workspace/examples/gen/BUILD
+++ b/examples/gen/BUILD
diff --git a/base_workspace/examples/go/BUILD b/examples/go/BUILD
index dd0846110c..dd0846110c 100644
--- a/base_workspace/examples/go/BUILD
+++ b/examples/go/BUILD
diff --git a/base_workspace/examples/go/README.md b/examples/go/README.md
index 69bcc4c664..69bcc4c664 100644
--- a/base_workspace/examples/go/README.md
+++ b/examples/go/README.md
diff --git a/base_workspace/examples/go/fib.go b/examples/go/fib.go
index 43d8a499ba..43d8a499ba 100644
--- a/base_workspace/examples/go/fib.go
+++ b/examples/go/fib.go
diff --git a/base_workspace/examples/go/lib1/BUILD b/examples/go/lib1/BUILD
index fb400772ef..fb400772ef 100644
--- a/base_workspace/examples/go/lib1/BUILD
+++ b/examples/go/lib1/BUILD
diff --git a/base_workspace/examples/go/lib1/fail_test.go b/examples/go/lib1/fail_test.go
index 5ef41a3b4d..5ef41a3b4d 100644
--- a/base_workspace/examples/go/lib1/fail_test.go
+++ b/examples/go/lib1/fail_test.go
diff --git a/base_workspace/examples/go/lib1/lib1.go b/examples/go/lib1/lib1.go
index f42494770d..f42494770d 100644
--- a/base_workspace/examples/go/lib1/lib1.go
+++ b/examples/go/lib1/lib1.go
diff --git a/base_workspace/examples/go/lib1/lib1_test.go b/examples/go/lib1/lib1_test.go
index 8eb88a0aca..8eb88a0aca 100644
--- a/base_workspace/examples/go/lib1/lib1_test.go
+++ b/examples/go/lib1/lib1_test.go
diff --git a/base_workspace/examples/java-native/README.md b/examples/java-native/README.md
index fb37462bf3..fb37462bf3 100644
--- a/base_workspace/examples/java-native/README.md
+++ b/examples/java-native/README.md
diff --git a/base_workspace/examples/java-native/src/main/java/com/example/myproject/BUILD b/examples/java-native/src/main/java/com/example/myproject/BUILD
index 717625343b..717625343b 100644
--- a/base_workspace/examples/java-native/src/main/java/com/example/myproject/BUILD
+++ b/examples/java-native/src/main/java/com/example/myproject/BUILD
diff --git a/base_workspace/examples/java-native/src/main/java/com/example/myproject/Greeter.java b/examples/java-native/src/main/java/com/example/myproject/Greeter.java
index 4123f2e202..4123f2e202 100644
--- a/base_workspace/examples/java-native/src/main/java/com/example/myproject/Greeter.java
+++ b/examples/java-native/src/main/java/com/example/myproject/Greeter.java
diff --git a/base_workspace/examples/java-native/src/main/resources/BUILD b/examples/java-native/src/main/resources/BUILD
index 8347a3555a..8347a3555a 100644
--- a/base_workspace/examples/java-native/src/main/resources/BUILD
+++ b/examples/java-native/src/main/resources/BUILD
diff --git a/base_workspace/examples/java-native/src/main/resources/greeting.txt b/examples/java-native/src/main/resources/greeting.txt
index 09170083fc..09170083fc 100644
--- a/base_workspace/examples/java-native/src/main/resources/greeting.txt
+++ b/examples/java-native/src/main/resources/greeting.txt
diff --git a/base_workspace/examples/java-native/src/test/java/com/example/myproject/BUILD b/examples/java-native/src/test/java/com/example/myproject/BUILD
index 838107650c..838107650c 100644
--- a/base_workspace/examples/java-native/src/test/java/com/example/myproject/BUILD
+++ b/examples/java-native/src/test/java/com/example/myproject/BUILD
diff --git a/base_workspace/examples/java-native/src/test/java/com/example/myproject/Fail.java b/examples/java-native/src/test/java/com/example/myproject/Fail.java
index 7b947c6e96..7b947c6e96 100644
--- a/base_workspace/examples/java-native/src/test/java/com/example/myproject/Fail.java
+++ b/examples/java-native/src/test/java/com/example/myproject/Fail.java
diff --git a/base_workspace/examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java b/examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java
index f14b7d234a..f14b7d234a 100644
--- a/base_workspace/examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java
+++ b/examples/java-native/src/test/java/com/example/myproject/TestCustomGreeting.java
diff --git a/base_workspace/examples/java-native/src/test/java/com/example/myproject/TestHello.java b/examples/java-native/src/test/java/com/example/myproject/TestHello.java
index d50e6e503f..d50e6e503f 100644
--- a/base_workspace/examples/java-native/src/test/java/com/example/myproject/TestHello.java
+++ b/examples/java-native/src/test/java/com/example/myproject/TestHello.java
diff --git a/base_workspace/examples/java-skylark/README.md b/examples/java-skylark/README.md
index 970a859f54..970a859f54 100644
--- a/base_workspace/examples/java-skylark/README.md
+++ b/examples/java-skylark/README.md
diff --git a/base_workspace/examples/java-skylark/src/main/java/com/example/myproject/BUILD b/examples/java-skylark/src/main/java/com/example/myproject/BUILD
index 10ca2d440d..10ca2d440d 100644
--- a/base_workspace/examples/java-skylark/src/main/java/com/example/myproject/BUILD
+++ b/examples/java-skylark/src/main/java/com/example/myproject/BUILD
diff --git a/base_workspace/examples/java-skylark/src/main/java/com/example/myproject/Greeter.java b/examples/java-skylark/src/main/java/com/example/myproject/Greeter.java
index b4d8516dc9..b4d8516dc9 100644
--- a/base_workspace/examples/java-skylark/src/main/java/com/example/myproject/Greeter.java
+++ b/examples/java-skylark/src/main/java/com/example/myproject/Greeter.java
diff --git a/base_workspace/examples/java-skylark/src/main/resources/BUILD b/examples/java-skylark/src/main/resources/BUILD
index 8347a3555a..8347a3555a 100644
--- a/base_workspace/examples/java-skylark/src/main/resources/BUILD
+++ b/examples/java-skylark/src/main/resources/BUILD
diff --git a/base_workspace/examples/java-skylark/src/main/resources/greeting.txt b/examples/java-skylark/src/main/resources/greeting.txt
index 17654db5a1..17654db5a1 100644
--- a/base_workspace/examples/java-skylark/src/main/resources/greeting.txt
+++ b/examples/java-skylark/src/main/resources/greeting.txt
diff --git a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/BUILD b/examples/java-skylark/src/test/java/com/example/myproject/BUILD
index 36c4cc3a67..36c4cc3a67 100644
--- a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/BUILD
+++ b/examples/java-skylark/src/test/java/com/example/myproject/BUILD
diff --git a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/Fail.java b/examples/java-skylark/src/test/java/com/example/myproject/Fail.java
index 079e1e9f04..079e1e9f04 100644
--- a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/Fail.java
+++ b/examples/java-skylark/src/test/java/com/example/myproject/Fail.java
diff --git a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/TestHello.java b/examples/java-skylark/src/test/java/com/example/myproject/TestHello.java
index d50e6e503f..d50e6e503f 100644
--- a/base_workspace/examples/java-skylark/src/test/java/com/example/myproject/TestHello.java
+++ b/examples/java-skylark/src/test/java/com/example/myproject/TestHello.java
diff --git a/base_workspace/examples/objc/BUILD b/examples/objc/BUILD
index 0499d61258..0499d61258 100644
--- a/base_workspace/examples/objc/BUILD
+++ b/examples/objc/BUILD
diff --git a/base_workspace/examples/objc/PrenotCalculator/AppDelegate.h b/examples/objc/PrenotCalculator/AppDelegate.h
index 75b1f1da38..75b1f1da38 100644
--- a/base_workspace/examples/objc/PrenotCalculator/AppDelegate.h
+++ b/examples/objc/PrenotCalculator/AppDelegate.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/AppDelegate.m b/examples/objc/PrenotCalculator/AppDelegate.m
index f6ecc4d6c3..f6ecc4d6c3 100644
--- a/base_workspace/examples/objc/PrenotCalculator/AppDelegate.m
+++ b/examples/objc/PrenotCalculator/AppDelegate.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/CalculatedValues.h b/examples/objc/PrenotCalculator/CalculatedValues.h
index 026fadf6ca..026fadf6ca 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CalculatedValues.h
+++ b/examples/objc/PrenotCalculator/CalculatedValues.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/CalculatedValues.m b/examples/objc/PrenotCalculator/CalculatedValues.m
index 2e401cb1c1..2e401cb1c1 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CalculatedValues.m
+++ b/examples/objc/PrenotCalculator/CalculatedValues.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.h b/examples/objc/PrenotCalculator/CalculatorViewController.h
index 60dbc83bb8..60dbc83bb8 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.h
+++ b/examples/objc/PrenotCalculator/CalculatorViewController.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.m b/examples/objc/PrenotCalculator/CalculatorViewController.m
index 5d26fefcc0..5d26fefcc0 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.m
+++ b/examples/objc/PrenotCalculator/CalculatorViewController.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.xib b/examples/objc/PrenotCalculator/CalculatorViewController.xib
index 7ed3f42c60..7ed3f42c60 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CalculatorViewController.xib
+++ b/examples/objc/PrenotCalculator/CalculatorViewController.xib
diff --git a/base_workspace/examples/objc/PrenotCalculator/CoreData.h b/examples/objc/PrenotCalculator/CoreData.h
index 2b55bb1404..2b55bb1404 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CoreData.h
+++ b/examples/objc/PrenotCalculator/CoreData.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/CoreData.m b/examples/objc/PrenotCalculator/CoreData.m
index 43a1e89122..43a1e89122 100644
--- a/base_workspace/examples/objc/PrenotCalculator/CoreData.m
+++ b/examples/objc/PrenotCalculator/CoreData.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion
index aae30cd305..aae30cd305 100644
--- a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion
+++ b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/.xccurrentversion
diff --git a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents
index 1cd3e57dae..1cd3e57dae 100644
--- a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents
+++ b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.0.xcdatamodel/contents
diff --git a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents
index 80b28dd35a..80b28dd35a 100644
--- a/base_workspace/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents
+++ b/examples/objc/PrenotCalculator/DataModel.xcdatamodeld/DataModel-1.1.xcdatamodel/contents
diff --git a/base_workspace/examples/objc/PrenotCalculator/Equation.h b/examples/objc/PrenotCalculator/Equation.h
index c04fc705e4..c04fc705e4 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Equation.h
+++ b/examples/objc/PrenotCalculator/Equation.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/Equation.m b/examples/objc/PrenotCalculator/Equation.m
index 4894e82b93..4894e82b93 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Equation.m
+++ b/examples/objc/PrenotCalculator/Equation.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/Expression.h b/examples/objc/PrenotCalculator/Expression.h
index f5b2dcf63e..f5b2dcf63e 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Expression.h
+++ b/examples/objc/PrenotCalculator/Expression.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/Expression.m b/examples/objc/PrenotCalculator/Expression.m
index 68e954170c..68e954170c 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Expression.m
+++ b/examples/objc/PrenotCalculator/Expression.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/Literal.h b/examples/objc/PrenotCalculator/Literal.h
index 62ee13c466..62ee13c466 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Literal.h
+++ b/examples/objc/PrenotCalculator/Literal.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/Literal.m b/examples/objc/PrenotCalculator/Literal.m
index c103f46510..c103f46510 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Literal.m
+++ b/examples/objc/PrenotCalculator/Literal.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/PrenotCalculator-Info.plist b/examples/objc/PrenotCalculator/PrenotCalculator-Info.plist
index 178f34c4c0..178f34c4c0 100644
--- a/base_workspace/examples/objc/PrenotCalculator/PrenotCalculator-Info.plist
+++ b/examples/objc/PrenotCalculator/PrenotCalculator-Info.plist
diff --git a/base_workspace/examples/objc/PrenotCalculator/Resources/test.txt b/examples/objc/PrenotCalculator/Resources/test.txt
index 3dc3aa5164..3dc3aa5164 100644
--- a/base_workspace/examples/objc/PrenotCalculator/Resources/test.txt
+++ b/examples/objc/PrenotCalculator/Resources/test.txt
diff --git a/base_workspace/examples/objc/PrenotCalculator/ValuesViewController.h b/examples/objc/PrenotCalculator/ValuesViewController.h
index 27055b905f..27055b905f 100644
--- a/base_workspace/examples/objc/PrenotCalculator/ValuesViewController.h
+++ b/examples/objc/PrenotCalculator/ValuesViewController.h
diff --git a/base_workspace/examples/objc/PrenotCalculator/ValuesViewController.m b/examples/objc/PrenotCalculator/ValuesViewController.m
index 333ea11b1f..333ea11b1f 100644
--- a/base_workspace/examples/objc/PrenotCalculator/ValuesViewController.m
+++ b/examples/objc/PrenotCalculator/ValuesViewController.m
diff --git a/base_workspace/examples/objc/PrenotCalculator/main.m b/examples/objc/PrenotCalculator/main.m
index f521bd84bb..f521bd84bb 100644
--- a/base_workspace/examples/objc/PrenotCalculator/main.m
+++ b/examples/objc/PrenotCalculator/main.m
diff --git a/base_workspace/examples/objc/README.md b/examples/objc/README.md
index 045264fed6..045264fed6 100644
--- a/base_workspace/examples/objc/README.md
+++ b/examples/objc/README.md
diff --git a/base_workspace/examples/objc/expression_prebuilt.a b/examples/objc/expression_prebuilt.a
index 8bb74bbb3b..8bb74bbb3b 100644
--- a/base_workspace/examples/objc/expression_prebuilt.a
+++ b/examples/objc/expression_prebuilt.a
Binary files differ
diff --git a/base_workspace/examples/proto/BUILD b/examples/proto/BUILD
index 2228fc4398..2228fc4398 100644
--- a/base_workspace/examples/proto/BUILD
+++ b/examples/proto/BUILD
diff --git a/base_workspace/examples/proto/test.proto b/examples/proto/test.proto
index 16a6dc335a..16a6dc335a 100644
--- a/base_workspace/examples/proto/test.proto
+++ b/examples/proto/test.proto
diff --git a/base_workspace/examples/py/BUILD b/examples/py/BUILD
index 6eecd4a4f3..6eecd4a4f3 100644
--- a/base_workspace/examples/py/BUILD
+++ b/examples/py/BUILD
diff --git a/base_workspace/examples/py/bin.py b/examples/py/bin.py
index 53e917e491..53e917e491 100644
--- a/base_workspace/examples/py/bin.py
+++ b/examples/py/bin.py
diff --git a/base_workspace/examples/py/lib.py b/examples/py/lib.py
index a27d4ce47c..a27d4ce47c 100644
--- a/base_workspace/examples/py/lib.py
+++ b/examples/py/lib.py
diff --git a/compile.sh b/compile.sh
index a9394283eb..5b83b32b1b 100755
--- a/compile.sh
+++ b/compile.sh
@@ -115,9 +115,10 @@ EOF
esac
}
# Create symlinks so we can use tools from the base_workspace.
rm -f base_workspace/tools && ln -s $(pwd)/tools base_workspace/tools
rm -f base_workspace/third_party && ln -s $(pwd)/third_party base_workspace/third_party
+rm -f base_workspace/examples && ln -s $(pwd)/examples base_workspace/examples
case "${PLATFORM}" in
linux)
@@ -115,9 +115,10 @@ EOF
esac
}
-# Create symlinks so we can use tools from the base_workspace.
+# Create symlinks so we can use tools and examples from the base_workspace.
rm -f base_workspace/tools && ln -s $(pwd)/tools base_workspace/tools
rm -f base_workspace/third_party && ln -s $(pwd)/third_party base_workspace/third_party